SVG <symbol> sprite preview | svg-sprite

### A) Inline SVG with embedded sprite

- ## icon--add

- ## icon--add--glyph

- ## icon--add--outline

- ## icon--add--solid

- ## icon--api

- ## icon--apis

- ## icon--app-services

- ## icon--applications

- ## icon--apps

- ## icon--arrow--down

- ## icon--arrow--left

- ## icon--arrow--right

- ## icon--arrow--up

- ## icon--arrows

- ## icon--asleep

- ## icon--asleep--glyph

- ## icon--attachment

- ## icon--awake

- ## icon--back-to-top

- ## icon--block-chain

- ## icon--calendar

- ## icon--caret--down

- ## icon--caret--left

- ## icon--caret--right

- ## icon--caret--up

- ## icon--cf-apps

- ## icon--chat

- ## icon--checkmark

- ## icon--checkmark--glyph

- ## icon--checkmark--outline

- ## icon--checkmark--solid

- ## icon--chevron--down

- ## icon--chevron--left

- ## icon--chevron--right

- ## icon--chevron--up

- ## icon--close

- ## icon--close--glyph

- ## icon--close--outline

- ## icon--close--solid

- ## icon--cloud-foundry

- ## icon--code

- ## icon--console

- ## icon--containers

- ## icon--copy

- ## icon--copy--glyph

- ## icon--crash

- ## icon--dashboard

- ## icon--data

- ## icon--delete

- ## icon--delete--glyph

- ## icon--devices

- ## icon--devops

- ## icon--document

- ## icon--dollars

- ## icon--download

- ## icon--download--glyph

- ## icon--draggable

- ## icon--edit

- ## icon--edit--glyph

- ## icon--email

- ## icon--error

- ## icon--error--glyph

- ## icon--error--outline

- ## icon--error--solid

- ## icon--favorite

- ## icon--favorite--outline

- ## icon--favorite--solid

- ## icon--filter

- ## icon--filter--glyph

- ## icon--finance

- ## icon--financial

- ## icon--folder

- ## icon--folder--glyph

- ## icon--folder-add

- ## icon--forum

- ## icon--functions

- ## icon--grid

- ## icon--header--avatar

- ## icon--header--chevron

- ## icon--header--close

- ## icon--header--contact

- ## icon--header--docs

- ## icon--header--hamburger

- ## icon--header--help

- ## icon--header--notification

- ## icon--header--search

- ## icon--header--ticket

- ## icon--header--user

- ## icon--help

- ## icon--help--glyph

- ## icon--help--outline

- ## icon--help--solid

- ## icon--hpa

- ## icon--hpa--stress

- ## icon--info

- ## icon--info--glyph

- ## icon--info--outline

- ## icon--info--solid

- ## icon--infrastructure

- ## icon--integration

- ## icon--iot

- ## icon--launch

- ## icon--launch--glyph

- ## icon--light

- ## icon--light--glyph

- ## icon--link

- ## icon--list

- ## icon--locked

- ## icon--maximize

- ## icon--menu

- ## icon--minimize

- ## icon--mobile

- ## icon--network

- ## icon--new-tab

- ## icon--notification-off

- ## icon--notification-on

- ## icon--open-whisk

- ## icon--overflow-menu

- ## icon--pa

- ## icon--pa--stress

- ## icon--pause

- ## icon--pause--glyph

- ## icon--pause--outline

- ## icon--pause--solid

- ## icon--play

- ## icon--play--glyph

- ## icon--play--outline

- ## icon--play--solid

- ## icon--portfolio

- ## icon--power

- ## icon--power--glyph

- ## icon--predictive

- ## icon--purchase

- ## icon--restart

- ## icon--restart--glyph

- ## icon--save

- ## icon--schematics

- ## icon--search

- ## icon--search--glyph

- ## icon--security

- ## icon--services

- ## icon--settings

- ## icon--settings--glyph

- ## icon--star--outline

- ## icon--star--solid

- ## icon--start

- ## icon--start--glyph

- ## icon--start--outline

- ## icon--stop

- ## icon--stop--glyph

- ## icon--stop--outline

- ## icon--stop--solid

- ## icon--storage

- ## icon--subtract--glyph

- ## icon--subtract--outline

- ## icon--subtract--solid

- ## icon--terminal

- ## icon--unlock

- ## icon--unlocked

- ## icon--upload

- ## icon--user

- ## icon--visibility-off

- ## icon--visibility-on

- ## icon--warning

- ## icon--warning--glyph

- ## icon--warning--outline

- ## icon--warning--solid

- ## icon--watson

- ## icon--whisk

### B) Inline SVG with external sprite (IE 9-11 with polyfill only)

- ## icon--add

- ## icon--add--glyph

- ## icon--add--outline

- ## icon--add--solid

- ## icon--api

- ## icon--apis

- ## icon--app-services

- ## icon--applications

- ## icon--apps

- ## icon--arrow--down

- ## icon--arrow--left

- ## icon--arrow--right

- ## icon--arrow--up

- ## icon--arrows

- ## icon--asleep

- ## icon--asleep--glyph

- ## icon--attachment

- ## icon--awake

- ## icon--back-to-top

- ## icon--block-chain

- ## icon--calendar

- ## icon--caret--down

- ## icon--caret--left

- ## icon--caret--right

- ## icon--caret--up

- ## icon--cf-apps

- ## icon--chat

- ## icon--checkmark

- ## icon--checkmark--glyph

- ## icon--checkmark--outline

- ## icon--checkmark--solid

- ## icon--chevron--down

- ## icon--chevron--left

- ## icon--chevron--right

- ## icon--chevron--up

- ## icon--close

- ## icon--close--glyph

- ## icon--close--outline

- ## icon--close--solid

- ## icon--cloud-foundry

- ## icon--code

- ## icon--console

- ## icon--containers

- ## icon--copy

- ## icon--copy--glyph

- ## icon--crash

- ## icon--dashboard

- ## icon--data

- ## icon--delete

- ## icon--delete--glyph

- ## icon--devices

- ## icon--devops

- ## icon--document

- ## icon--dollars

- ## icon--download

- ## icon--download--glyph

- ## icon--draggable

- ## icon--edit

- ## icon--edit--glyph

- ## icon--email

- ## icon--error

- ## icon--error--glyph

- ## icon--error--outline

- ## icon--error--solid

- ## icon--favorite

- ## icon--favorite--outline

- ## icon--favorite--solid

- ## icon--filter

- ## icon--filter--glyph

- ## icon--finance

- ## icon--financial

- ## icon--folder

- ## icon--folder--glyph

- ## icon--folder-add

- ## icon--forum

- ## icon--functions

- ## icon--grid

- ## icon--header--avatar

- ## icon--header--chevron

- ## icon--header--close

- ## icon--header--contact

- ## icon--header--docs

- ## icon--header--hamburger

- ## icon--header--help

- ## icon--header--notification

- ## icon--header--search

- ## icon--header--ticket

- ## icon--header--user

- ## icon--help

- ## icon--help--glyph

- ## icon--help--outline

- ## icon--help--solid

- ## icon--hpa

- ## icon--hpa--stress

- ## icon--info

- ## icon--info--glyph

- ## icon--info--outline

- ## icon--info--solid

- ## icon--infrastructure

- ## icon--integration

- ## icon--iot

- ## icon--launch

- ## icon--launch--glyph

- ## icon--light

- ## icon--light--glyph

- ## icon--link

- ## icon--list

- ## icon--locked

- ## icon--maximize

- ## icon--menu

- ## icon--minimize

- ## icon--mobile

- ## icon--network

- ## icon--new-tab

- ## icon--notification-off

- ## icon--notification-on

- ## icon--open-whisk

- ## icon--overflow-menu

- ## icon--pa

- ## icon--pa--stress

- ## icon--pause

- ## icon--pause--glyph

- ## icon--pause--outline

- ## icon--pause--solid

- ## icon--play

- ## icon--play--glyph

- ## icon--play--outline

- ## icon--play--solid

- ## icon--portfolio

- ## icon--power

- ## icon--power--glyph

- ## icon--predictive

- ## icon--purchase

- ## icon--restart

- ## icon--restart--glyph

- ## icon--save

- ## icon--schematics

- ## icon--search

- ## icon--search--glyph

- ## icon--security

- ## icon--services

- ## icon--settings

- ## icon--settings--glyph

- ## icon--star--outline

- ## icon--star--solid

- ## icon--start

- ## icon--start--glyph

- ## icon--start--outline

- ## icon--stop

- ## icon--stop--glyph

- ## icon--stop--outline

- ## icon--stop--solid

- ## icon--storage

- ## icon--subtract--glyph

- ## icon--subtract--outline

- ## icon--subtract--solid

- ## icon--terminal

- ## icon--unlock

- ## icon--unlocked

- ## icon--upload

- ## icon--user

- ## icon--visibility-off

- ## icon--visibility-on

- ## icon--warning

- ## icon--warning--glyph

- ## icon--warning--outline

- ## icon--warning--solid

- ## icon--watson

- ## icon--whisk